| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.ElastiCache.Types.TimeRangeFilter
Description
Documentation
data TimeRangeFilter Source #
Filters update actions from the service updates that are in available status during the time range.
See: newTimeRangeFilter smart constructor.
Constructors
| TimeRangeFilter' | |
Instances
newTimeRangeFilter :: TimeRangeFilter Source #
Create a value of TimeRangeFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:endTime:TimeRangeFilter', timeRangeFilter_endTime - The end time of the time range filter
$sel:startTime:TimeRangeFilter', timeRangeFilter_startTime - The start time of the time range filter
timeRangeFilter_endTime :: Lens' TimeRangeFilter (Maybe UTCTime) Source #
The end time of the time range filter
timeRangeFilter_startTime :: Lens' TimeRangeFilter (Maybe UTCTime) Source #
The start time of the time range filter